#!/usr/bin/env python
# -*- coding: utf-8 -*-
#

__version__ = '0.0.15'

from .config import API_URL_MAPPING
from .authentication import Auth
from .service import Request, AppService, UserService
